summaryrefslogtreecommitdiff
path: root/src/upb_srcsink.h
diff options
context:
space:
mode:
authorJoshua Haberman <joshua@reverberate.org>2010-06-07 17:27:54 -0700
committerJoshua Haberman <joshua@reverberate.org>2010-06-07 17:27:54 -0700
commitfbc57ee4882eca6321f8e1f2f5a3b8fae448605b (patch)
tree073d6dd9f5e814d934f33ec4f91ef41c5acfc57f /src/upb_srcsink.h
parentcfe0ef08c15d038865e9618af25de76c8304ad9e (diff)
More work on the decoder.
Diffstat (limited to 'src/upb_srcsink.h')
-rw-r--r--src/upb_srcsink.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/src/upb_srcsink.h b/src/upb_srcsink.h
index 6a60f31..3a57cc8 100644
--- a/src/upb_srcsink.h
+++ b/src/upb_srcsink.h
@@ -71,7 +71,7 @@ upb_status *upb_sink_status(upb_sink *sink);
/* upb_bytesrc ****************************************************************/
// Returns the next string in the stream. NULL is returned on error or eof.
// The string must be at least "minlen" bytes long.
//
// A ref is passed to the caller, though the caller is encouraged to pass the
// ref back to the bytesrc with upb_bytesrc_recycle(). This can help reduce
@@ -140,6 +140,7 @@ typedef struct {
typedef struct {
upb_src_vtable *vtbl;
upb_status status;
+ bool eof;
#ifndef NDEBUG
int state; // For debug-mode checking of API usage.
#endif
@@ -71,7 +71,7 @@ upb_status *upb_sink_status(upb_sink *sink);
/* upb_bytesrc ****************************************************************/
// Returns the next string in the stream. NULL is returned on error or eof.
-// The string must be at least "minlen" bytes long.
+// The string must be at least "minlen" bytes long unless the stream is eof.
//
// A ref is passed to the caller, though the caller is encouraged to pass the
generated by cgit on debian on lair
contact matthew@masot.net with questions or feedback